<?php
/**
 * birva functions and definitions
 *
 * @package birva
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'birva_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function birva_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on birva, use a find and replace
	 * to change 'birva' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'birva', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
    
    //Theme Title.
    add_theme_support('title-tag');
    
    // Tell the TinyMCE editor to use a custom stylesheet
    add_editor_style( get_template_directory() . '/css/editor-style.css' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'birva' ),
	) );
    
    //Custom Header
    $birva_defaults = array(
    	'default-image'          => '',
    	'random-default'         => false,
    	'width'                  => 0,
    	'height'                 => 0,
    	'flex-height'            => false,
    	'flex-width'             => false,
    	'default-text-color'     => '',
    	'header-text'            => true,
    	'uploads'                => true,
    	'wp-head-callback'       => '',
    	'admin-head-callback'    => '',
    	'admin-preview-callback' => '',
    );
    add_theme_support( 'custom-header', $birva_defaults );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		 'audio', 'gallery', 'video', 'quote'  
	) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'birva_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // birva_setup
add_action( 'after_setup_theme', 'birva_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function birva_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'birva' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widgettitle">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'birva_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function birva_scripts() {

	// Google fonts 
    function briva_google_fonts_one() {
	   $briva_query_args = array(
		  'family' => 'Oswald:300,400,700',
		  'subset' => 'latin,latin-ext',
	   );
	   wp_register_style( 'briva_google_fonts_one', add_query_arg( $briva_query_args, "//fonts.googleapis.com/css" ), array(), null );
    }        
    add_action('wp_enqueue_scripts', 'briva_google_fonts_one');
    
    function briva_google_fonts_two() {
	   $briva_query_args = array(
		  'family' => 'Open+Sans:400,300,400italic,600,700',
		  'subset' => 'latin,latin-ext',
	   );
	   wp_register_style( 'briva_google_fonts_two', add_query_arg( $briva_query_args, "//fonts.googleapis.com/css" ), array(), null );
    }        
    add_action('wp_enqueue_scripts', 'briva_google_fonts_two');
    
	// CSS Skeleton
	wp_enqueue_style( 'base',  get_template_directory_uri().'/css/base.css');
	wp_enqueue_style( 'skeleton',  get_template_directory_uri().'/css/skeleton.css');
	// Custom Css
	wp_enqueue_style( 'component',  get_template_directory_uri().'/css/component.css');
	wp_enqueue_style( 'font-awesome.min',  get_template_directory_uri().'/css/font-awesome.min.css');
 


	// Javascript
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
  	wp_enqueue_script( 'birva-navigation', get_template_directory_uri() . '/js/navigation.js', array(), false, true );
	wp_enqueue_script( 'birva-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), false, true );
	wp_enqueue_script( 'easing', get_template_directory_uri() . '/js/jquery.easing.min.js', array(), '', true );
	wp_enqueue_script( 'retina', get_template_directory_uri() . '/js/retina.js', array(), '', true );
	wp_enqueue_script( 'jquery.isotope.min', get_template_directory_uri() . '/js/jquery.isotope.min.js', array(), '', true );
	wp_enqueue_script( 'masonryResponsive', get_template_directory_uri() . '/js/masonryResponsive.js', array(), '', true );
	wp_enqueue_script( 'jquery.parallax-1.1.3', get_template_directory_uri() . '/js/jquery.parallax-1.1.3.js', array(), '', true );
	wp_enqueue_script( 'jquery.flexisel', get_template_directory_uri() . '/js/jquery.flexisel.js', array(), '', true );
	wp_enqueue_script( 'tweetable.jquery', get_template_directory_uri() . '/js/tweetable.jquery.js', array(), '', true );
	wp_enqueue_script( 'jquery.timeago', get_template_directory_uri() . '/js/jquery.timeago.js', array(), '', true );
	wp_enqueue_script( 'jquery.cycle.all.min', get_template_directory_uri() . '/js/jquery.cycle.all.min.js', array(), '', true );
	wp_enqueue_script( 'bellows', get_template_directory_uri() . '/js/bellows.js', array(), '', true );
	wp_enqueue_script( 'parallaxInit', get_template_directory_uri() . '/js/parallaxInit.js', array(), '', true );
	wp_enqueue_script( 'jquery.fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array(), '', true );
	wp_enqueue_script( 'scripts', get_template_directory_uri() . '/js/scripts.js', array(), '', true );
	wp_enqueue_script( 'like', get_template_directory_uri() . '/js/post-like.min.js', array(), '', true );
	wp_enqueue_script( 'birva', get_template_directory_uri() . '/js/birva.js', array(), '', true );
	wp_enqueue_script( 'switcher', get_template_directory_uri() . '/js/switcher.js', array(), '', true );

}
add_action( 'wp_enqueue_scripts', 'birva_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
* Metaboxes
*/
require get_template_directory() . '/metabox.php';  
 
/**
* Plugins
*/
require_once(get_template_directory() . '/TGM.php');


/**
* Pagination
*/
function wpbeginner_numeric_posts_nav() {

	if( is_singular() )
		return;

	global $wp_query;

	$birva_ret = '';

	/** Stop execution if there's only 1 page */
	if( $wp_query->max_num_pages <= 1 )
		return;

	$birva_paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
	$birva_max   = intval( $wp_query->max_num_pages );

	/**	Add current page to the array */
	if ( $birva_paged >= 1 )
		$birva_links[] = $birva_paged;

	/**	Add the pages around the current page to the array */
	if ( $birva_paged >= 3 ) {
		$birva_links[] = $birva_paged - 1;
		$birva_links[] = $birva_paged - 2;
	}

	if ( ( $birva_paged + 2 ) <= $birva_max ) {
		$birva_links[] = $birva_paged + 2;
		$birva_links[] = $birva_paged + 1;
	}

	$birva_ret .= '<div class="pagination"><ul>';

	$birva_ret .= '<li><a href="'.esc_url( get_pagenum_link( 1 ) ).'"><i class="icon-double-angle-left"></i></a></li>';

	/**	Previous Post Link */
	if ( get_previous_posts_link() )
		$birva_ret .= '<li>'.get_previous_posts_link('<i class="icon-angle-left"></i>').'</li>';  

	/**	Link to first page, plus ellipses if necessary */
	if ( ! in_array( 1, $birva_links ) ) {
		$class = 1 == $birva_paged ? ' class="current"' : '';

		$birva_ret .= '<li><a '.$class.' href="'.esc_url( get_pagenum_link( 1 ) ).'">1</a></li>'; 

		if ( ! in_array( 2, $birva_links ) )
			$birva_ret .= '<li> - </li>';
	}

	/**	Link to current page, plus 2 pages in either direction if necessary */
	sort( $birva_links );
	foreach ( (array) $birva_links as $link ) {
		$class = $birva_paged == $link ? ' class="current"' : '';
		$birva_ret .= '<li><a '.$class.' href="'.esc_url( get_pagenum_link( $link ) ).'">'.$link.'</a></li>';
	}

	/**	Link to last page, plus ellipses if necessary */
	if ( ! in_array( $birva_max, $birva_links ) ) {
		if ( ! in_array( $birva_max - 1, $birva_links ) )
			$birva_ret .= '<li> - </li>';

		$class = $birva_paged == $birva_max ? ' class="current"' : '';
		$birva_ret .= '<li><a '.$class.' href="'.esc_url( get_pagenum_link( $birva_max ) ).'">'.$birva_max.'</a></li>';
	}

	/**	Next Post Link */
	if ( get_next_posts_link() )
		$birva_ret .= '<li>'.get_next_posts_link('<i class="icon-angle-right"></i>').'</li>';

	$birva_ret .= '<li><a href="'.esc_url( get_pagenum_link( $birva_max ) ).'"><i class="icon-double-angle-right"></i></a></li>';

	$birva_ret .=  '</ul></div>';


	return $birva_ret;

}

   


// comment list
function mytheme_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$birva_tag = 'div';
		$birva_add_below = 'comment';
	} else {
		$birva_tag = 'li';
		$birva_add_below = 'div-comment';
	}
?>

		<<?php echo $birva_tag ?> id="comment-<?php comment_ID() ?>">

	<article class="comment">

		<header class="comment-author">
			<?php echo get_avatar( $comment, 88 ); ?>                                 
		</header>
		<section class="comment-details">


			<div class="author-name"> <a title="" href="#"> <?php echo get_comment_author(); ?> </a> </div>
			<div class="commentmetadata"> <?php echo get_comment_date('d M Y'); ?>  </div>
			<div class="comment-body">
				<div class="comment-content">

					<p><?php comment_text(); ?></p> 

					<?php if ( $comment->comment_approved == '0' ) : ?>
						<p class="comment-awaiting-moderation">Your comment is awaiting moderation</p> 
					<?php endif; ?>
				</div>
			</div>
			<div class="reply"> <?php comment_reply_link( array_merge( $args, array( 'add_below' => $birva_add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => __( 'Reply >', 'birva' ) ) ) ); ?> </div>
 
 
		</section>
	</article>
<?php
}








