<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 * Please read them CAREFULLY.
 *
 * You also should read the changelog to know what has been changed before updating.
 *
 * For more information, please visit:
 * @link http://www.deluxeblogtips.com/meta-box/
 */


add_filter( 'rwmb_meta_boxes', 'birva_register_meta_boxes' );

/**
 * Register meta boxes
 *
 * Remember to change "your_prefix" to actual prefix in your project
 *
 * @return void
 */
function birva_register_meta_boxes( $meta_boxes )
{
	/**
	 * prefix of meta keys (optional)
	 * Use underscore (_) at the beginning to make keys hidden
	 * Alt.: You also can make prefix empty to disable it
	 */
	// Better has an underscore as last sign
	$birva_prefix = 'birva_';

    // 1st meta box
    $birva_meta_boxes[] = array(
        // Meta box id, UNIQUE per meta box. Optional since 4.1.5
        'id' => 'standard',

        // Meta box title - Will appear at the drag and drop handle bar. Required.
        'title' => __( 'Subtitle', 'birva' ),

        // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
        'pages' => array( 'post' ),

        // Where the meta box appear: normal (default), advanced, side. Optional.
        'context' => 'side',

        // Order of meta box: high (default), low. Optional.
        'priority' => 'high',

        // Auto save: true, false (default). Optional.
        'autosave' => true,


        // List of meta fields
        'fields' => array(  
            // RADIO BUTTONS
            array(
                'name'    => __( ' ', 'birva' ),
                'id'      => "{$birva_prefix}sub",
                'type'    => 'text',
                'desc' => __('Subtitle', 'birva' ), 
                'std' => '',
            ), 
        ),
        
    );

	// 1st meta box
	$birva_meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id' => 'standard',

		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title' => __( 'Block Background color', 'birva' ),

		// Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
		'pages' => array( 'block' ),

		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context' => 'side',

		// Order of meta box: high (default), low. Optional.
		'priority' => 'high',

		// Auto save: true, false (default). Optional.
		'autosave' => true,


		// List of meta fields
		'fields' => array(  
			// RADIO BUTTONS
			array(
				'name'    => __( ' ', 'birva' ),
				'id'      => "{$birva_prefix}block",
				'type'    => 'radio',
                'desc' => __('You can change Theme colors in Appearance->Customize', 'birva' ),
				// Array of 'value' => 'Label' pairs for radio options.
				// Note: the 'value' is stored in meta field, not the 'Label'
				'options' => array( 
					'dark' => __( 'Dark', 'birva' ),
					'light' => __( 'Light', 'birva' ),
				),
				'std' => 'light',
			), 
		),
		
	);


    // 1st meta box
    $birva_meta_boxes[] = array(
        // Meta box id, UNIQUE per meta box. Optional since 4.1.5
        'id' => 'port',

        // Meta box title - Will appear at the drag and drop handle bar. Required.
        'title' => __( 'Project Info', 'birva' ),

        // Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
        'pages' => array( 'portfolio' ),

        // Where the meta box appear: normal (default), advanced, side. Optional.
        'context' => 'side',

        // Order of meta box: high (default), low. Optional.
        'priority' => 'high',

        // Auto save: true, false (default). Optional.
        'autosave' => true,


        // List of meta fields
        'fields' => array(   
            array(
                'name'    => __( ' ', 'birva' ),
                'id'      => "{$birva_prefix}feat",
                'type'    => 'select',
                'desc' => __('', 'birva' ),
                // Array of 'value' => 'Label' pairs for radio options.
                // Note: the 'value' is stored in meta field, not the 'Label'
                'options' => array( 
                    '0' => __( 'Not Featured', 'birva' ),
                    '1' => __( 'Featured', 'birva' ),
                ),
                'std' => '0',
            ), 
            array(
                'name'    => __( 'URL', 'birva' ),
                'id'      => "{$birva_prefix}url",
                'type'    => 'text',
                'desc' => __(' ', 'birva' ),
                'std' => '',
            ),   
            array(
                'name'    => __( 'Category', 'birva' ),
                'id'      => "{$birva_prefix}cat",
                'type'    => 'text',
                'desc' => __(' ', 'birva' ),
                'std' => '',
            ),  
            array(
                'name'    => __( 'Client', 'birva' ),
                'id'      => "{$birva_prefix}cli",
                'type'    => 'text',
                'desc' => __(' ', 'birva' ),
                'std' => '',
            ), 
        ),
        
    );
 

	return $birva_meta_boxes;
}
add_action('admin_head', 'birva_wpse_50092_script_enqueuer');

function birva_wpse_50092_script_enqueuer() {
    global $current_screen; 

    echo <<<HTML
    	<style>
    		.rwmb-radio-wrapper .rwmb-input label {float: left; width: 100%; margin: 5px 0;}
    	</style>
        <script type="text/javascript"> 
        jQuery(document).ready( function($) {

            /**
             * Adjust visibility of the meta box at startup
            */
            if (($('#page_template').val() == 'pt-one-page.php')) {
                // show the meta box
                //$('#sss').show();
            } else {
                // hide your meta box
                //$('#sss').hide();
            }
             if (($('#page_template').val() == 'pt-one-page.php')) {
                // show the meta box
                //$('#sss').show();
            } else {
                // hide your meta box
               // $('#sss').hide();
            }

            /**
             * Live adjustment of the meta box visibility
            */
            $('#page_template').live('change', function(){
           		if ($(this).val() == 'pt-one-page.php') {
                    // show the meta box
                    //$('#sss').show();
                } else {
                    // hide your meta box
                    //$('#sss').hide();
                }
            });                 
        });    
        </script>
HTML;
}
